{% if filetype_loop == 0 %}
System Auth Control,Authorized Clients,Unauthorized Clients,Total Clients
{{ to_parse_dot1x.system_auth_control }},{{ to_parse_dot1x.sessions.authorized_clients }},{{ to_parse_dot1x.sessions.unauthorized_clients }},{{ to_parse_dot1x.sessions.total }}
{% else %}{% if filetype_loop == 1 %}
# Learn Dot1x Sessions
| System Auth Control | Authorized Clients | Unauthorized Clients | Total Clients |
| ------------------- | ------------------ | -------------------- | ------------- |
| {{ to_parse_dot1x.system_auth_control }} | {{ to_parse_dot1x.sessions.authorized_clients }} | {{ to_parse_dot1x.sessions.unauthorized_clients }} | {{ to_parse_dot1x.sessions.total }} |{% else %}{% if filetype_loop == 2 %}
<html><body>
<h1>Learn Dot1x/h1>
<table style="width:100%">
  <tr>
    <th>System Auth Control</th>
    <th>Authorized Clients</th>
    <th>Unauthorized Clients</th>
    <th>Total Clients</th>
  </tr>
  <tr>
    <td>{{ to_parse_dot1x.system_auth_control }}</td>
    <td>{{ to_parse_dot1x.sessions.authorized_clients }}</td>
    <td>{{ to_parse_dot1x.sessions.unauthorized_clients }}</td>
    <td>{{ to_parse_dot1x.sessions.total }}</td>
  </tr>
</table>
</body></html>{% else %}
# Learn dot1x Sessions
## System Auth Control: {{ to_parse_dot1x.system_auth_control }}
## Clients
### Authorized: {{ to_parse_dot1x.sessions.authorized_clients }}
### Unauthorized: {{ to_parse_dot1x.sessions.unauthorized_clients }}
### Total: {{ to_parse_dot1x.sessions.total }}
{% endif %}{% endif %}{% endif %}